@@ -17,11 +17,11 @@ PGObject
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 
 =head1 SYNOPSIS
@@ -109,8 +109,11 @@ Connects to the db using DBI and returns a db connection
 
 sub connect {
     my $self = shift;
-    return DBI->connect('dbi:Pg:dbname=' . $self->dbname, 
-                           $self->username, $self->password);
+    my $dbh =  DBI->connect('dbi:Pg:dbname=' . $self->dbname, 
+                           $self->username, $self->password) 
+    or die "Cound not connect to database!";
+    return $dbh;
+           
 }
 
 =head2 server_version
@@ -174,7 +177,8 @@ sub create {
                        $self->port     ? "-p " . $self->port . " "     : '' ,
                        $self->dbname   ? $self->dbname                 : '' )
                   );
-    my $stderr = capture_stderr sub{ `$command` };
+    my $stderr = capture_stderr sub{ local ($?, $!);
+				     `$command` };
     die $stderr if $stderr;
     return 1;
 }
@@ -238,7 +242,14 @@ sub run_file {
                         $self->dbname ? $self->dbname : ' ' ,
                         $log)
                   );
-    my $stderr = capture_stderr sub{ `$command` || print STDERR ' APPLICATION ERROR ' . "\n"; };
+    my $stderr = capture_stderr sub {
+	local ($?, $!);
+	my $result = `$command`;
+	print STDERR "\nAPPLICATION ERROR\n"
+	    if $? != 0;
+	return $result;
+    };
+
     print STDERR $stderr;
     print ERRLOG $stderr if $errlog;
     close ERRLOG if $errlog;
@@ -288,7 +299,8 @@ sub backup {
                   $self->port           ? "-p " . $self->port . " "     : '' ,
                   defined $args{format} ? "-F$args{format} "            : '' ,
                   qq(> "$tempfile" )));
-    my $stderr = capture_stderr { `$command` };
+    my $stderr = capture_stderr { local ($?, $!);
+				  `$command` };
     print STDERR $stderr;
     for my $err (split /\n/, $stderr) {
           die $err if $err =~ /(ERROR|FATAL)/;
@@ -335,7 +347,8 @@ sub backup_globals {
                   $self->host           ? "-h " . $self->host . " "     : '' ,
                   $self->port           ? "-p " . $self->port . " "     : '' ,
                   qq(> "$tempfile" )));
-    my $stderr = capture_stderr { `$command` };
+    my $stderr = capture_stderr { local ($?, $!);
+				  `$command` };
     print STDERR $stderr;
     for my $err (split /\n/, $stderr) {
           die $err if $err =~ /(ERROR|FATAL)/;
@@ -406,7 +419,8 @@ sub restore {
                   $self->port           ? "-p " . $self->port . " "     : '' ,
                   defined $args{format} ? "-F$args{format}"             : '' ,
                   qq("$args{file}")));
-    my $stderr = capture_stderr sub{ `$command` };
+    my $stderr = capture_stderr sub{ local ($?, $!);
+				     `$command` };
     print STDERR $stderr;
     print ERRLOG $stderr if $errlog;
     close ERRLOG if $errlog;
@@ -434,7 +448,8 @@ sub drop {
                   $self->host     ? "-h " . $self->host . " "     : '' ,
                   $self->port     ? "-p " . $self->port . " "     : '' ,
                   $self->dbname));
-    my $stderr = capture_stderr { `$command` };
+    my $stderr = capture_stderr { local ($?, $!);
+				  `$command` };
     die $stderr if $stderr =~ /(ERROR|FATAL)/;
     return 1;
 }
